@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -283,6 +283,36 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_88(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55e00
+#  define KIOCORE_DEPRECATED_VERSION_5_94(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_94(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56000
+#  define KIOCORE_DEPRECATED_VERSION_5_96(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_96(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KIOCORE_DEPRECATED_VERSION_5_97(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
@@ -350,7 +380,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -360,7 +390,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -547,6 +577,36 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_88(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_90(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55e00
+#  define KIOCORE_DEPRECATED_VERSION_5_94(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_94(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56000
+#  define KIOCORE_DEPRECATED_VERSION_5_96(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_96(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KIOCORE_DEPRECATED_VERSION_5_97(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
